Auth0FlutterWeb class

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

getLoggedInUserId() → Future
Fetches the currently authenticated user ID. Returns null if no user is authenticated.
handleWebLoginCallback(String? url) → Future<bool>
Fetches the currently authenticated user ID. Returns null if no user is authenticated.
logoutUser() → Future<void>
Logs out current user.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
userAuthentication({Future<void> afterLogin()?, required String screenHint}) → Future
If user is not authenticated, shows universal login. Returns user ID of logged in user.

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

auth0ClientId ↔ String
Retrieves the Auth0 ClientId.
getter/setter pair
auth0Domain ↔ String
Retrieves the Auth0 Domain.
getter/setter pair
instance → Auth0FlutterWeb
The instance of Auth0FlutterWeb.
final
redirectUri ↔ String
Retrieves the Auth0 ClientId.
getter/setter pair
scheme ↔ String?
Retrieves the custom scheme.
getter/setter pair

Static Methods

setPathUrlStrategy() → Future<void>