GetTokenSilentlyOptions class

Annotations

Constructors

GetTokenSilentlyOptions({String audience, bool ignoreCache, String redirect_uri, String scope, num timeoutInSeconds})
factory

Properties

audience → String
no setter
hashCode → int
The hash code for this object.
no setterinherited
ignoreCache → bool
no setter
redirect_uri → String
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scope → String
no setter
timeoutInSeconds → num
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited